import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import React, { PureComponent, cloneElement } from 'react';
import PropTypes from 'prop-types';
import MapContext from './map-context';
import assert from '../utils/assert';
const propTypes = {
  type: PropTypes.string.isRequired,
  id: PropTypes.string
};
let sourceCounter = 0;
export default class Source extends PureComponent {
  constructor(props) {
    super(props);

    _defineProperty(this, "id", void 0);

    _defineProperty(this, "type", void 0);

    _defineProperty(this, "_map", null);

    _defineProperty(this, "_sourceOptions", {});

    this.id = props.id || "jsx-source-".concat(sourceCounter++);
    this.type = props.type;
  }

  componentWillUnmount() {
    requestAnimationFrame(() => this._map.removeSource(this.id));
  }

  getSource() {
    return this._map.getSource(this.id);
  }

  _createSource() {
    const map = this._map;

    if (map.style._loaded) {
      map.addSource(this.id, this._sourceOptions);
    } else {
      map.once('styledata', () => this.forceUpdate());
    }
  }

  _updateSource() {
    const {
      _sourceOptions: sourceOptions,
      props
    } = this;
    assert(!props.id || props.id === this.id, 'source id changed');
    assert(props.type === this.type, 'source type changed');
    let changedKey = null;
    let changedKeyCount = 0;

    for (const key in props) {
      if (key !== 'children' && key !== 'id' && sourceOptions[key] !== props[key]) {
        sourceOptions[key] = props[key];
        changedKey = key;
        changedKeyCount++;
      }
    }

    const {
      type,
      _map: map
    } = this;
    const source = this.getSource();

    if (!source) {
      this._createSource();

      return;
    }

    if (!changedKeyCount) {
      return;
    }

    if (type === 'geojson') {
      source.setData(sourceOptions.data);
    } else if (type === 'image') {
      source.updateImage({
        url: sourceOptions.url,
        coordinates: sourceOptions.coordinates
      });
    } else if ((type === 'canvas' || type === 'video') && changedKeyCount === 1 && changedKey === 'coordinates') {
      source.setCoordinates(sourceOptions.coordinates);
    } else {
      map.removeSource(this.id);
      map.addSource(this.id, sourceOptions);
    }
  }

  _render(context) {
    this._map = context.map;

    this._updateSource();

    return React.Children.map(this.props.children, child => cloneElement(child, {
      source: this.id
    }));
  }

  render() {
    return React.createElement(MapContext.Consumer, null, this._render.bind(this));
  }

}

_defineProperty(Source, "propTypes", propTypes);
//# sourceMappingURL=source.js.map